/**
 * Describes the settings to use when activating a service
 */
export interface ServiceActivationOptions {
    /**
     * The client's preferred culture
     *
     * @remarks
     * Should be in form languagecode2-country/regioncode2 (i.e. "en-US")
     * See [CultureInfo.Name Property](https://docs.microsoft.com/en-us/dotnet/api/system.globalization.cultureinfo.name?view=netframework-4.8) for more
     * information about client culture formatting
     */
    clientCulture?: string;
    /**
     * The client's preferred UI culture
     *
     * @remarks
     * Should be in form languagecode2-country/regioncode2 (i.e. "en-US")
     * See [CultureInfo.Name Property](https://docs.microsoft.com/en-us/dotnet/api/system.globalization.cultureinfo.name?view=netframework-4.8) for more
     * information about client culture formatting
     */
    clientUICulture?: string;
    /**
     * A map that identifies the client and communicates permissions they have
     */
    clientCredentials?: {
        [key: string]: string;
    };
    /**
     * A map of data that may be useful to the service in its activation
     */
    activationArguments?: {
        [key: string]: string;
    };
    /**
     * The RPC target to offer the remote service for callbacks.
     */
    clientRpcTarget?: object;
}
